GenTxt

# The GenTxt General Analyzer

NOTE: GenTxt is no longer supported and is unavailable for download. It is superseded by TAIParse, a general English analyzer available at

http://www.textanalysis.com/Apps/POS_Tagger/pos_tagger.html

An older version that includes a semantic framework (yet to be incorporated into the above) is available at

http://www.textanalysis.com/Apps/Natural_Language_Processing/natural_language_processing.html

A knowledge base that embeds WordNet is also available from TAI.